@@ -70,9 +70,12 @@ class FirestoreClient(BaseClient):
         session: Any = None,
     ) -> WriteResult:
         data = model.dict(include=include, exclude=exclude)
-        _id: str = data["id"]
+
         collection_name = model.get_db_collection()
         collection = self.get_collection(collection_name)
+        if data["id"] is None:
+            data["id"] = self.generate_id(collection_name)
+        _id = data["id"]
 
         try:
             result = await force_async(collection.add)(data, _id)
