@@ -48,6 +48,7 @@ def setup_db(app: FastAPI) -> None:
 
         client = motor.motor_asyncio.AsyncIOMotorClient(
             settings.MONGODB_DSN,
+            connect=settings.MONGO_AUTO_CONNECT,
             minPoolSize=settings.mongodb_min_pool_size,
             maxPoolSize=settings.mongodb_max_pool_size,
         )
@@ -87,9 +88,7 @@ def get_db_client():
 
 
 def all_subclasses(cls):
-    return set(cls.__subclasses__()).union(
-        [s for c in cls.__subclasses__() for s in all_subclasses(c)]
-    )
+    return set(cls.__subclasses__()).union([s for c in cls.__subclasses__() for s in all_subclasses(c)])
 
 
 def get_models() -> list:
