@@ -74,7 +74,10 @@ class Serializer(CamelModel):
         return list(map(lambda x: clean_d(x), iterable))
 
     async def save(
-        self, include: set = None, exclude: set = None, rewrite_fields: dict = None,
+        self,
+        include: set = None,
+        exclude: set = None,
+        rewrite_fields: dict = None,
     ) -> Optional[str]:
         """
         If we have `model` attribute in Meta, it populates model with data
@@ -88,16 +91,12 @@ class Serializer(CamelModel):
         :return: id (str) that was saved
         """
         if hasattr(self, "Meta") and getattr(self.Meta, "model", None) is not None:
-            instance = self.Meta.model.__class__(**self.__values__)
-            ret = await instance.save(
-                include=include, exclude=exclude, rewrite_fields=rewrite_fields
-            )
+            instance = self.Meta.model.__class__(**self.__values__)  # type: ignore
+            ret = await instance.save(include=include, exclude=exclude, rewrite_fields=rewrite_fields)
             return ret
         return None
 
-    async def update_one(
-        self, _id: str, _data: dict, skip_defaults: bool = True
-    ) -> WriteResult:
+    async def update_one(self, _id: str, _data: dict, skip_defaults: bool = True) -> WriteResult:
         """
         If we have `model` attribute in Meta, it proxies filters & update data
         and after that returns actual result of update operation.
@@ -113,9 +112,7 @@ class Serializer(CamelModel):
             return await self.Meta.model.update_one(_id, _data)  # type: ignore
         raise DatabaseError(f"No Meta.model is defined for {self.__class__}")
 
-    async def update_many(
-        self, data: List[Tuple[str, dict]], skip_defaults: bool = True
-    ) -> WriteResult:
+    async def update_many(self, data: List[Tuple[str, dict]], skip_defaults: bool = True) -> WriteResult:
         """
         If we have `model` attribute in Meta, it proxies filters & update data
         and after that returns actual result of update operation.
