@@ -39,31 +39,31 @@ def gen_model(cls: Type, mode: FieldGenerationMode):
     Config = getattr(cls, "Config", getattr(Serializer, "Config"))
 
     if mode == FieldGenerationMode.RESPONSE:
-        excluded = Meta.exclude | Meta.write_only_fields
+        excluded = Meta.exclude | Meta.write_only_fields  # type: ignore
     else:
-        excluded = Meta.exclude | Meta.read_only_fields
+        excluded = Meta.exclude | Meta.read_only_fields  # type: ignore
 
-    if hasattr(Meta, "model") and Meta.model is not None:
-        for f, t in Meta.model.__fields__.items():
+    if hasattr(Meta, "model") and Meta.model is not None:  # type: ignore
+        for f, t in Meta.model.__fields__.items():  # type: ignore
             if f not in excluded:
                 f_def = t.default
                 if t.required:
                     f_def = Required
 
                 if t.shape == SHAPE_LIST:
-                    _type = List[t.type_]
+                    _type = List[t.type_]  # type: ignore
                 elif t.shape == SHAPE_SET:
-                    _type = Set[t.type_]
+                    _type = Set[t.type_]  # type: ignore
                 elif t.shape == SHAPE_MAPPING:
-                    _type = Mapping[t.key_field.type_, t.type_]
+                    _type = Mapping[t.key_field.type_, t.type_]  # type: ignore
                 elif t.shape == SHAPE_TUPLE:
-                    _type = t.type_
+                    _type = t.type_  # type: ignore
                 elif t.shape == SHAPE_TUPLE_ELLIPSIS:
-                    _type = Tuple[t.type_, ...]
+                    _type = Tuple[t.type_, ...]  # type: ignore
                 elif t.shape == SHAPE_SEQUENCE:
-                    _type = Sequence[t.type_]
+                    _type = Sequence[t.type_]  # type: ignore
                 else:
-                    _type = t.type_
+                    _type = t.type_  # type: ignore
                 _fields.update({f: (_type, f_def)})
 
     for f, t in cls.__fields__.items():
@@ -76,8 +76,8 @@ def gen_model(cls: Type, mode: FieldGenerationMode):
     if mode == FieldGenerationMode.REQUEST:
         response_model = gen_model(cls, mode=FieldGenerationMode.RESPONSE)
 
-        Serializer.Config = Config
-        model = create_model(cls.__name__, __base__=Serializer, **_fields)
+        Serializer.Config = Config  # type: ignore
+        model = create_model(cls.__name__, __base__=Serializer, **_fields)  # type: ignore
         setattr(model, "response_model", response_model)
         setattr(model, "Meta", Meta)
         setattr(model, "Config", Config)
@@ -89,4 +89,4 @@ def gen_model(cls: Type, mode: FieldGenerationMode):
 
         return model
 
-    return create_model(f"{cls.__name__}Response", __config__=Config, **_fields)
+    return create_model(f"{cls.__name__}Response", __config__=Config, **_fields)  # type: ignore
