@@ -26,7 +26,10 @@ class BaseClient(abc.ABC):
 
     @abc.abstractmethod
     async def upload_file(
-        self, file: UploadFile, bucket_name: str, parent_path: str = "",
+        self,
+        file: UploadFile,
+        bucket_name: str,
+        parent_path: str = "",
     ) -> File:
         pass
 
@@ -57,9 +60,7 @@ class BaseClient(abc.ABC):
         pass
 
     @abc.abstractmethod
-    async def delete_file(
-        self, bucket_name: str, file_path: str, recursive: bool = False
-    ) -> None:
+    async def delete_file(self, bucket_name: str, file_path: str, recursive: bool = False) -> None:
         """
         Deletes a file or folder from the specified bucket
 
@@ -74,23 +75,16 @@ class BaseClient(abc.ABC):
         pass
 
     @abc.abstractmethod
-    async def rename_file(
-        self, bucket_name: str, file_path: str, new_file_path: str
-    ) -> None:
+    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> File:
         pass
 
     @abc.abstractmethod
-    async def copy_file(
-        self, from_bucket: str, from_path: str, to_bucket: str, to_path: str
-    ) -> None:
+    async def copy_file(self, from_bucket: str, from_path: str, to_bucket: str, to_path: str) -> None:
         pass
 
     @abc.abstractmethod
-    async def create_temp_file_url(
-        self, bucket: str, path: str, expire_time_hours: int = 3
-    ) -> File:
-        """Enable file to be downloaded without auth via a URL temporarily
-        """
+    async def create_temp_file_url(self, bucket: str, path: str, expire_time_hours: int = 3) -> File:
+        """Enable file to be downloaded without auth via a URL temporarily"""
         pass
 
     @abc.abstractclassmethod
