@@ -20,6 +20,9 @@ from fa_common import (
 from .base_client import BaseClient
 from .model import File
 
+from google.auth.transport import requests
+from google.auth import compute_engine
+from google.auth.exceptions import RefreshError
 
 class GoogleStorageClient(BaseClient):
     """
@@ -226,15 +229,21 @@ class GoogleStorageClient(BaseClient):
         except NotFound:
             raise StorageError(f"Trying to delete a file {bucket_name}/{file_path} that doesn't exist.")
 
-    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> None:
+    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> File:
         bucket = await self._get_bucket(bucket_name)
         blob = bucket.blob(self.convert_path_in(file_path, bucket_name))
         if blob.exists():
-            await force_async(bucket.rename_blob)(blob, self.convert_path_in(new_file_path, bucket_name))
+            new_blob = await force_async(bucket.rename_blob)(
+                blob, self.convert_path_in(new_file_path, bucket_name)
+            )
         else:
             raise StorageError(f"Trying to rename a file {bucket_name}/{file_path} that doesn't exist.")
 
         LOG.debug(f"{file_path} renamed to {new_file_path}")
+        file = self.blob_to_file(new_blob, bucket_name)
+        if file is None:
+            raise StorageError("A file could not be created from the GCP blob")
+        return file
 
     async def copy_file(self, from_bucket: str, from_path: str, to_bucket: str, to_path: str) -> None:
         bucket = await self._get_bucket(from_bucket)
@@ -253,7 +262,18 @@ class GoogleStorageClient(BaseClient):
         blob = await self._get_blob(bucket, path)
         expire_time = datetime.timedelta(hours=expire_time_hours)
 
-        url = blob.generate_signed_url(expiration=expire_time, version="v4")
+        try:
+            # GCE signer does not work as expected causing generate_signed_url to fail without private key associated with service account supplied.
+            # This happens even when cloud run is executed with the service account.
+            # See https://github.com/googleapis/google-auth-library-python/issues/50.
+            # Current workaround is to supply the credentials as an argument.
+            # See https://gist.github.com/jezhumble/91051485db4462add82045ef9ac2a0ec.
+            signing_credentials = compute_engine.IDTokenCredentials(requests.Request(), "", service_account_email=self.gcp_storage._credentials.service_account_email)
+            url = blob.generate_signed_url(expiration=expire_time, credentials=signing_credentials, version="v4")
+        except RefreshError:
+            # Refresh error may occur if Compute engine metadata is unavailable, in which case signing is done using json supplied.
+            # Retaining this so that existing usage that does not utilise cloud run does not break.
+            url = blob.generate_signed_url(expiration=expire_time, version="v4")
         LOG.info(f"Created url: {url} for file download")
         file_ref = self.blob_to_file(blob, bucket)
         if file_ref is None:
