@@ -156,11 +156,7 @@ class MinioClient(BaseClient):
         obj = None
         try:
             obj = await force_async(self.minio.get_object)(bucket_name, file_path)
-            bytes_stream = BytesIO()
-            for d in obj.stream(32 * 1024):
-                bytes_stream.write(d)
-
-            return bytes_stream
+            return BytesIO(obj.read())
         except MinioException as err:
             if hasattr(err, "code") and err.code == "NoSuchKey":
                 return None
@@ -176,13 +172,10 @@ class MinioClient(BaseClient):
         try:
             stats = await force_async(self.minio.stat_object)(bucket_name, file_path)
             LOG.info(stats)
-            if stats is None:
-                return False
-            return True
+            return stats is not None
         except MinioException as err:
             if hasattr(err, "code") and err.code == "NoSuchKey":
                 return False
-
             LOG.error(str(err))
             raise StorageError("Error checking if {} exists", file_path)
 
@@ -219,7 +212,7 @@ class MinioClient(BaseClient):
             LOG.error(err)
             raise err
 
-    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> None:
+    async def rename_file(self, bucket_name: str, file_path: str, new_file_path: str) -> File:
         try:
             await force_async(self.minio.copy_object)(
                 bucket_name, new_file_path, CopySource(bucket_name, file_path)
@@ -228,6 +221,11 @@ class MinioClient(BaseClient):
             LOG.error(f"Error renaming {file_path} to {new_file_path} in bucket {bucket_name}: {str(err)}")
             raise StorageError(f"Somthing went wrong renaming {file_path} to {new_file_path}")
         await self.delete_file(bucket_name, file_path)
+        obj = await force_async(self.minio.stat_object)(bucket_name, new_file_path)
+        file = self.object_to_file(obj, bucket_name, new_file_path)
+        if file is None:
+            raise StorageError("A file could not be created from the Minio obj")
+        return file
 
     async def copy_file(self, from_bucket: str, from_path: str, to_bucket: str, to_path: str) -> None:
         try:
